@@ -93,7 +93,6 @@ gnotebook <- function(
 ##' @export
 ##' @rdname gnotebook
 ##' @method add GNotebook
-##' @S3method add GNotebook
 add.GNotebook <- function(obj, child, expand, fill, anchor, ...) {
   ## process passed in args
   args <- list(...)
@@ -113,7 +112,6 @@ add.GNotebook <- function(obj, child, expand, fill, anchor, ...) {
 ##' @export
 ##' @rdname gnotebook
 ##' @method dispose GNotebook
-##' @S3method dispose GNotebook
 dispose.GNotebook <- function(obj, ...) {
   obj$remove_current_page()
 }
@@ -126,10 +124,9 @@ dispose.GNotebook <- function(obj, ...) {
 ##' @export
 ##' @rdname gnotebook
 ##' @method names GNotebook
-##' @S3method names GNotebook
 "names.GNotebook" <- function(x) x$get_names()
 
-
+#####' @param x notebook object
 ##' svalue method
 ##'
 ##' Set the currently raised tab by index (the default) or name
@@ -140,8 +137,8 @@ dispose.GNotebook <- function(obj, ...) {
 ##' @usage \method{svalue}{GNotebook} (obj, index=TRUE, ...) <- value
 ##' @rdname gnotebook
 ##' @method svalue<- GNotebook
-##' @S3method svalue<- GNotebook
 "svalue<-.GNotebook" <- function(obj, index=TRUE,  ...,value) {
+    if (is.null(index)) index <- TRUE
     if (!index) {
         index = TRUE
         value = match(value, names(obj))
@@ -149,17 +146,18 @@ dispose.GNotebook <- function(obj, ...) {
     NextMethod()
 }
 
+## ##' @param x \code{GNotebook} object
+
+
 ##' "[" method
 ##'
 ##' The notebook object contains pages referenced by index. This allows access to underlying page.
-##' @param x \code{GNotebook} object
 ##' @param i row index. Either integer or character
 ##' @param j ignored
 ##' @param drop ignored
 ##' @export
 ##' @rdname gnotebook
 ##' @method [ GNotebook
-##' @S3method [ GNotebook
 "[.GNotebook" <- function(x, i, j, ..., drop=TRUE) {
     if (is.character(i))
         i <- match(i, names(x))
@@ -177,7 +175,6 @@ dispose.GNotebook <- function(obj, ...) {
 ##' @param handler handler
 ##' @param action passed along to handler via \code{h[["action"]]}.
 ##' @method addHandlerChanged GNotebook
-##' @S3method addHandlerChanged GNotebook
 addHandlerChanged.GNotebook <- function(obj, handler, action=NULL, ...) {
   NextMethod()
 }
